@@ -4,13 +4,13 @@ use strict;
 use warnings;
 
 # ABSTRACT: Documentation and tools for using Platypus with the C programming language
-our $VERSION = '0.45'; # VERSION
+our $VERSION = '0.47'; # VERSION
 
 
 sub native_type_map
 {
-  require FFI::Platypus::ConfigData;
-  FFI::Platypus::ConfigData->config('type_map');
+  require FFI::Platypus::ShareConfig;
+  FFI::Platypus::ShareConfig->get('type_map');
 }
 
 1;
@@ -27,7 +27,7 @@ FFI::Platypus::Lang::C - Documentation and tools for using Platypus with the C p
 
 =head1 VERSION
 
-version 0.45
+version 0.47
 
 =head1 SYNOPSIS
 
